# Problem

::: openscvx.problem.Problem.__init__
    options:
      show_source: false
      show_root_heading: true

## ScpConfig

::: openscvx.config.ScpConfig.__init__
    options:
      show_source: false
      show_root_heading: true

## DiscretizationConfig

::: openscvx.config.DiscretizationConfig.__init__
    options:
      show_source: false
      show_root_heading: true

## PropagationConfig

::: openscvx.config.PropagationConfig.__init__
    options:
      show_source: false
      show_root_heading: true

## SimConfig

::: openscvx.config.SimConfig.__init__
    options:
      show_source: false
      show_root_heading: true

## ConvexSolverConfig

::: openscvx.config.ConvexSolverConfig.__init__
    options:
      show_source: false
      show_root_heading: true

## DevConfig

::: openscvx.config.DevConfig.__init__
    options:
      show_source: false
      show_root_heading: true 